@@ -1,8 +1,8 @@
-package MooseX::Types::Email; # git description: v0.006-19-gec41ca1
+package MooseX::Types::Email; # git description: v0.007-8-g4cf93bd
 # ABSTRACT: Email address validation type constraints for Moose.
 # KEYWORDS: moose type constraint email address message abstract
 
-our $VERSION = '0.007';
+our $VERSION = '0.008';
 
 use MooseX::Types
     -declare => [qw/EmailAddress EmailMessage EmailAddresses EmailMessages/];
@@ -15,11 +15,25 @@ use if MooseX::Types->VERSION >= 0.42, 'namespace::autoclean';
 subtype EmailAddress,
   as Str,
   where { Email::Valid->address($_) },
-  message { "Must be a valid e-mail address" };
+  message { "Must be a valid e-mail address" },
+  ( $Moose::VERSION >= 2.0200
+      ? inline_as {
+          $_[0]->parent()->_inline_check( $_[1] ) . ' && '
+              . qq{ Email::Valid->address($_[1]) };
+      }
+      : ()
+  );
 
 subtype EmailMessage,
   as Object, where { Email::Abstract->new($_) },
-  message { "Must be something Email::Abstract recognizes" };
+  message { "Must be something Email::Abstract recognizes" },
+  ( $Moose::VERSION >= 2.0200
+      ? inline_as {
+          $_[0]->parent()->_inline_check( $_[1] ) . ' && '
+              . qq{ Email::Abstract->new($_[1]) };
+      }
+      : ()
+  );
 
 coerce EmailMessage,
   from Object,
@@ -37,7 +51,14 @@ coerce EmailAddresses,
 subtype EmailMessages,
   as ArrayRef[Object],
   where { not grep { not Email::Abstract->new($_) } @$_  },
-  message { 'Must be an arrayref of something Email::Abstract recognizes' };
+  message { 'Must be an arrayref of something Email::Abstract recognizes' },
+  ( $Moose::VERSION >= 2.0200
+      ? inline_as {
+          $_[0]->parent()->_inline_check( $_[1] ) . ' && '
+              . qq{ not grep { not Email::Abstract->new(\$_) } \@{ $_[1] } };
+      }
+      : ()
+  );
 
 # no coercion from Object, as that would also catch existing Email::Abstract
 # objects and its subtypes.
@@ -56,7 +77,7 @@ MooseX::Types::Email - Email address validation type constraints for Moose.
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -107,13 +128,24 @@ messages.
 Karen Etheridge C<< <ether@cpan.org> >> added support for lists of email
 addresses and messages.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-Types-Email>
+(or L<bug-MooseX-Types-Email@rt.cpan.org|mailto:bug-MooseX-Types-Email@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
+
 =head1 AUTHOR
 
 Tomas Doran (t0m) <bobtfish@bobtfish.net
 
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Tomas Doran (t0m) Alexander Hartmaier Chris Nehren
+=for stopwords Karen Etheridge Tomas Doran (t0m) Alexander Hartmaier Chris Nehren Gregory Oschwald
 
 =over 4
 
@@ -133,6 +165,10 @@ Alexander Hartmaier <abraxxa@cpan.org>
 
 Chris Nehren <apeiron@cpan.org>
 
+=item *
+
+Gregory Oschwald <goschwald@maxmind.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENCE
